"""Re-exported from oasyce_core. Do not add logic here."""
from oasyce_core.services.exposure.window import *  # noqa: F401,F403
from oasyce_core.services.exposure.window import BondRecord, LiabilityWindow
