"""Re-exported from oasyce_core. Do not add logic here."""
from oasyce_core.crypto.keys import *  # noqa: F401,F403
from oasyce_core.crypto.keys import generate_keypair, load_or_create_keypair, sign, verify, DEFAULT_KEY_DIR
