"""
L3 TEE Engine - Trusted Execution Environment & zk-PoE Module

This module provides secure compute enclave simulation for Layer 3
of the Oasyce Claw Plugin Engine architecture.
"""

from .zk_poe_engine import TEEComputeEngine

__all__ = ['TEEComputeEngine']
